
import 'package:dio/dio.dart' as dioplugn;
import 'package:pretty_dio_logger/pretty_dio_logger.dart';

class MyHttpUtil {
  late dioplugn.Dio dio;
  late dioplugn.BaseOptions options;

  MyHttpUtil({Map<String, dynamic>? header}) {
    Map<String, dynamic> defaultHeader = {
      "Accept": "application/json",
      "Content-Type": "application/json;charset=UTF-8"
    };
    options = dioplugn.BaseOptions(
      connectTimeout: 15000,
      receiveTimeout: 3000,
      headers: header ?? defaultHeader,
    );
    dio = dioplugn.Dio(options);
    dio.interceptors.add(PrettyDioLogger(requestHeader: true, requestBody: true, responseBody: true, responseHeader: false, error: true, compact: true, maxWidth: 90));
  }

  Future<ResponseModel> get(url, {data, cancelToken, bool analyze = true, bool isShowToast = true}) async {
    try {
      // dio.options.headers['token'] = MainService.to.token;
      dioplugn.Response response = await dio.get(url, queryParameters: data, cancelToken: cancelToken);

      bool isSuccess = false;
      int code = -1;
      String msg = "数据请求失败";
      dynamic resData;
      if (response.statusCode == 200) {
        Map datas = response.data;
        if (datas.containsKey("status")) {
          code = datas["status"];
        }
        if (datas.containsKey("code")) {
          code = datas["code"];
        }
        if (datas.containsKey("data")) {
          resData = datas["data"];
        }
        if (datas.containsKey("callback")) {
          resData = datas["callback"];
        }
        if (datas.containsKey("msg")) {
          msg = datas["msg"];
        }
        if (code >= 1) {
          isSuccess = true;
        } else {
          // isShowToast ? ToastUtil.showToast(msg) : null;
        }
        return ResponseModel(isSuccess: isSuccess, code: code, msg: msg, data: resData);
      } else {
        // isShowToast ? ToastUtil.showToast("网络加载失败哦～") : null;
        return ResponseModel(isSuccess: false, code: code, msg: msg, data: resData);
      }
    } on dioplugn.DioError catch (e) {
      // isShowToast ? ToastUtil.showToast("网络加载失败哦～") : null;
      // ToastUtil.closeLoading();
      throw e.error;
    }
  }

  Future<ResponseModel> post(url, {data, options, cancelToken, Function(int, int)? onSendProgress, bool analyze = true, bool isShowToast = true}) async {
    try {
      // dio.options.headers['token'] = MainService.to.token;
      dioplugn.Response response = await dio.post(
        url,
        data: data,
        cancelToken: cancelToken,
        onSendProgress: onSendProgress,
      );
      bool isSuccess = false;
      int code = -1;
      String msg = "msg";
      dynamic resData;
      if (response.statusCode == 200) {
        Map datas = response.data;
        if (datas.containsKey("status")) {
          code = datas["status"];
        }
        if (datas.containsKey("code")) {
          code = datas["code"];
        }
        if (datas.containsKey("data")) {
          resData = datas["data"];
        }
        if (datas.containsKey("callback")) {
          resData = datas["callback"];
        }
        if (datas.containsKey("msg")) {
          msg = datas["msg"];
        }

        resData ??= datas;
        if (code >= 1) {
          isSuccess = true;
        } else {
          // isShowToast ? ToastUtil.showToast(msg) : null;
        }
        return ResponseModel(isSuccess: isSuccess, code: code, msg: msg, data: resData);
      } else {
        // isShowToast ? ToastUtil.showToast("网络加载失败哦～") : null;
        return ResponseModel(isSuccess: false, code: code, msg: msg, data: resData);
      }
    } on dioplugn.DioError catch (e) {
      // ToastUtil.closeLoading();
      // isShowToast ? ToastUtil.showToast("网络加载失败哦～") : null;
      print("error ${e.error}");
      throw e.error;
    }
  }
}

class ResponseModel {
  final bool isSuccess;
  final int code;
  final String msg;
  dynamic data;

  ResponseModel({required this.isSuccess, required this.code, required this.msg, required this.data});
}
