
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:wht_pay_plugin/sdp_model.dart';
import 'package:wht_pay_plugin/sdp_payment_bean.dart';
import 'package:wht_pay_plugin/sdpay_result.dart';

class WhtPayPlugin {
  /// 声明回调通道
  static const MethodChannel _channel = MethodChannel('sdp_pay');
  /// 声明监听回调通道
  static const EventChannel _eventChannel =  EventChannel('sdp_pay/event');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  FlutterPay(){

  }


  Stream<dynamic>? _onBatteryStateChanged;

  /// 初始化监听
  Stream<dynamic>? get onBatteryStateChanged {
    _onBatteryStateChanged ??= _eventChannel.receiveBroadcastStream();
    return _onBatteryStateChanged;
  }

  /// 初始化SDK
  /// sk 必须
  /// isDialog 是否使用Dialog 弹窗登录 非必须 默认值false 非Dialog登录
  /// debug 是否开启调试模式 非必须 默认true 开启
  /// 使用一键登录传入 SERVICE_TYPE_LOGIN 2  使用号码校验传入 SERVICE_TYPE_AUTH  1 默认值 2
  static Future<dynamic> initSdk({ required SDPPayInitBean config}) async {
    // /// 判断视图配置
    // Map<String, dynamic> data = getConfig().toJson();
    // if (config == null || config.toString().isEmpty) {
    //   config = getConfig();
    // } else {
    //   data.addAll(config.toJson());
    // }

    ///监听原生调起Flutter方法
    _channel.setMethodCallHandler((call) async {
      switch (call.method) {
        case "onSDPTPayResponse":
          print("监听原生调起Flutter方法 == ${call.method}");
          break;
      }
    });

    return await _channel.invokeMethod("init", {
      'wx_app_id': config.wxAppId,
      'store_id': config.storeId,
      'create_ip': config.createIp,
      'mer_no': config.merNo,
      "queryURL" : config.queryURL
    });
  }

  ///统一支付
  static Future<dynamic> payment({required SDPPaymentBean bean})async {
    var result =  await _channel.invokeMethod("payment", {
      'order_amt': bean.orderAmt,
      'goods_name': bean.goodsName,
      'product_code': bean.productCode,
    });
    if(result != null){
      return SdpayResult.fromJson(result);
    }else{
      return result;
    }
  }

  static Future<dynamic> generalPayment({required Map parameter,required SDPPaymentBean bean})async{

    if(parameter.isNotEmpty){
      parameter["order_amt"] = bean.orderAmt;
      parameter["goods_name"] = bean.goodsName;
      parameter["product_code"] = bean.productCode;
      var result =  await _channel.invokeMethod("payment", parameter);
      if(result != null){
        return SdpayResult.fromJson(result);
      }else{
        return result;
      }
    }else{
      return false;
    }
  }

  /// 数据监听
  static payMentListen({ required Function onEvent, Function? onError}) async {
    _eventChannel.receiveBroadcastStream().listen(onEvent as void Function(dynamic)?, onError: onError, onDone: null, cancelOnError: null);
  }


}
